<?php
/**
 * store-locator class.
 *
 * @category   Class
 * @package    StoreLocator
 * @subpackage WordPress
 * @author
 * @since      1.0.0
 * php version 7.3.9
 */

namespace StoreLocatorWidget;

// Security Note: Blocks direct access to the plugin PHP files.
defined('ABSPATH') || die();

/**
 * Class Plugin
 *
 * Main Plugin class
 *
 * @since 1.0.0
 */
class Widgets
{

    /**
     * Instance
     *
     * @since 1.0.0
     * @access private
     * @static
     *
     * @var Plugin The single instance of the class.
     */
    private static $instance = null;

    /**
     * Instance
     *
     * Ensures only one instance of the class is loaded or can be loaded.
     *
     * @return Plugin An instance of the class.
     * @since 1.0.0
     * @access public
     *
     */
    public static function instance()
    {
        if (is_null(self::$instance)) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    /**
     * Include Widgets files
     *
     * Load widgets files
     *
     * @since 1.0.0
     * @access private
     */
    private function include_widgets_files()
    {


        require_once 'widgets/store-locator/widget.php';

    }

    public function register_categories()
    {
        \Elementor\Plugin::instance()->elements_manager->add_category(
            'store-locator-category',
            array(
                'title' => __('store-locator components', 'store-locator'),
                'icon' => 'fa fa-ship',
            )
        );
    }


    /**
     * widget_scripts
     *
     * Load required plugin core files.
     *
     * @access public
     */
    public function widget_scripts()
    {

             wp_register_script('store-locator-widget-script-main', plugins_url('dist/main.js', ELEMENTOR_STORE_LOCATOR_WIDGET), array(), 'integration-aa1ca62-1713861184', true);

    }

    /**
     * Register Widgets
     *
     * Register new Elementor widgets.
     *
     * @since 1.0.0
     * @access public
     */
    public function register_widgets()
    {
        // It's now safe to include Widgets files.
        $this->include_widgets_files();

        // Register the plugin widget classes.

        \Elementor\Plugin::instance()->widgets_manager->register_widget_type(new Widgets\STORE_LOCATOR());


    }

    /**
     *  Plugin class constructor
     *
     * Register plugin action hooks and filters
     *
     * @since 1.0.0
     * @access public
     */
    public function __construct()
    {
        // Register the widgets.
        add_action('elementor/elements/categories_registered', array($this, 'register_categories'));
        add_action('elementor/frontend/after_register_scripts', array($this, 'widget_scripts'));
        add_action('elementor/widgets/widgets_registered', array($this, 'register_widgets'));

    }
}

// Instantiate the Widgets class.
Widgets::instance();
