<?php
/**
 * DeviensPro class.
 *
 * @category   Class
 * @package    StoreLocatorWidget
 * @subpackage WordPress
 * @author
 * @since      1.0.0
 * php version 7.3.9
 */

namespace StoreLocatorWidget\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

// Security Note: Blocks direct access to the plugin PHP files.
defined('ABSPATH') || die();

/**
 * store-locator-widget widget class.
 *
 * @since 1.0.0
 */
class STORE_LOCATOR extends Widget_Base
{
    /**
     * Class constructor.
     *
     * @param array $data Widget data.
     * @param array $args Widget arguments.
     */
    public function __construct($data = array(), $args = null)
    {
        parent::__construct($data, $args);

        #wp_register_style(' store-locator-widget-styles-vendors', plugins_url('assets/css/2.f87fbcaa.chunk.css', STORE_LOCATOR_WIDGET));
        #wp_register_style('store-locator-widget-styles-main', plugins_url('assets/css/main.6fdcdd19.chunk.css', STORE_LOCATOR_WIDGET));

    }

    public function get_style_depends()
    {
        return []; //[ 'store-locator-widget-styles-vendors','store-locator-widget-styles-main' ];
    }

    public function get_script_depends()
    {
        return ['store-locator-widget-script-main'];
    }

    /**
     * Retrieve the widget name.
     *
     * @return string Widget name.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_name()
    {
        return 'store-locator';
    }

    /**
     * Retrieve the widget title.
     *
     * @return string Widget title.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_title()
    {
        return __('store-locator', 'elementor-store-locator-widget');
    }

    /**
     * Retrieve the widget icon.
     *
     * @return string Widget icon.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_icon()
    {
        return 'fa';
    }

    /**
     * Retrieve the list of categories the widget belongs to.
     *
     * Used to determine where to display the widget in the editor.
     *
     * Note that currently Elementor supports only one category.
     * When multiple categories passed, Elementor uses the first one.
     *
     * @return array Widget categories.
     * @since 1.0.0
     *
     * @access public
     *
     */
    public function get_categories()
    {
        return array('store-locator-widget-category');
    }

    /**
     * Register the widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function _register_controls()
    {
        $this->start_controls_section(
            'section_content',
            array(
                'label' => __( 'Content', 'elementor-store-locator-widget' ),
            )
        );



            $this->add_control(
                'projectId',
                array(
                    'label' => __('projectId', 'elementor-store-locator-widget'),
                    'type' => Controls_Manager::TEXT,
                    'default' => __('', 'elementor-store-locator-widget'),
                )
            );


            $this->add_control(
                'displayMode',
                array(
                    'label' => __('displayMode', 'elementor-store-locator-widget'),
                    'type' => Controls_Manager::TEXT,
                    'default' => __('mobile|default|dialog|inline', 'elementor-store-locator-widget'),
                )
            );


            $this->add_control(
                'dialogPosition',
                array(
                    'label' => __('dialogPosition', 'elementor-store-locator-widget'),
                    'type' => Controls_Manager::TEXT,
                    'default' => __('LEFT|RIGHT', 'elementor-store-locator-widget'),
                )
            );

          $this->add_control(
                'openByDefault',
                array(
                    'label' => __('openByDefault', 'elementor-store-locator-widget'),
                    'type' => Controls_Manager::TEXT,
                    'default' => __('true|false', 'elementor-store-locator-widget'),
                )
            );

            $this->add_control(
                'language',
                array(
                    'label' => __('language', 'elementor-store-locator-widget'),
                    'type' => Controls_Manager::TEXT,
                    'default' => __('en|fr', 'elementor-store-locator-widget'),
                )
            );

            $this->add_control(
                'zoom',
                array(
                    'label' => __('zoom', 'elementor-store-locator-widget'),
                    'type' => Controls_Manager::TEXT,
                    'default' => __('15', 'elementor-store-locator-widget'),
                )
            );

        $this->end_controls_section();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        $this->add_render_attribute(
            'store-locator-wrapper',
            [

                     'projectId' => wp_kses( $settings['projectId'], array() ),

                     'displayMode' => wp_kses( $settings['displayMode'], array() ),

                     'dialogPosition' => wp_kses( $settings['dialogPosition'], array() ),
                     'zoom' => wp_kses( $settings['zoom'], array() ),

                     'language' => wp_kses( $settings['language'], array() ),
                     'openByDefault' => wp_kses( $settings['openByDefault'], array() ),


            ]
        );
        ?>

        <store-locator <?php echo $this->get_render_attribute_string( 'store-locator-wrapper' ); ?>></store-locator>
        <?php
    }

    /**
     * Render the widget output in the editor.
     *
     * Written as a Backbone JavaScript template and used to generate the live preview.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function _content_template()
    {
        ?>
        <#
            view.addRenderAttribute(
                'store-locator-wrapper',
                    {

                           'projectId': settings.projectId,

                           'displayMode': settings.displayMode,

                           'dialogPosition': settings.dialogPosition,

                           'language': settings.language,

                           'openByDefault': settings.openByDefault,
                           'zoom': settings.zoom,

                    }

            );
        #>

        <store-locator {{{ view.getRenderAttributeString( 'store-locator-wrapper' ) }}}></store-locator>
        <?php
    }
}
